/* EBCS -- Main and global definitions
   Copyright (C) 2000, 2001 Free Software Foundation, Inc.
   Written by Stephane Carrez (stcarrez@worldnet.fr)	

This file is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

In addition to the permissions in the GNU General Public License, the
Free Software Foundation gives you unlimited permission to link the
compiled version of this file with other programs, and to distribute
those programs without any restriction coming from the use of this
file.  (The General Public License restrictions do apply in other
respects; for example, they cover modification of the file, and
distribution when not linked into another program.)

This file is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#ifndef _EBCS_H
#define _EBCS_H

#include "board.h"

/* Control of Fan, Light and mains detection on Port A.  */
#define EBCS_CMD_FAN     (BOARD_LCD_5) /* Port A, bit 5 */
#define EBCS_CMD_LIGHT   (BOARD_LCD_6) /* Port A, bit 6 */
#define EBCS_SENSE_LIGHT (BOARD_KEY_0) /* Port A, bit 0 */
#define EBCS_SENSE_MAINS (BOARD_PEB_2) /* Port E, bit 2 */

/* Control of LCD panel (maps to SPI outputs).  */
#define EBCS_LCD_SDATA   (BOARD_LCD_1) /* Port D, bit 3 */
#define EBCS_LCD_CLK     (BOARD_LCD_2) /* Port D, bit 4 */
#define EBCS_LCD_POWER   (BOARD_LCD_3) /* Port D, bit 5 */

/* LCD panel feedback.  */
#define EBCS_SENSE_KEY   (BOARD_KEY_3) /* Port A, bit 7 */
#define EBCS_BATH_TEMP   (BOARD_PEB_0) /* Port E, bit 0 */

/* Temperature and humidity sensors.  */
#define EBCS_TEMPERATURE  (BOARD_PEB_3) /* Port E, bit 3 */
#define EBCS_PRESENCE     (BOARD_PEB_1) /* Port E, bit 1 */
#define EBCS_HUMIDITY     (BOARD_KEY_2) /* Port A, bit 2 */
#define EBCS_HUMIDITY_REF (BOARD_KEY_1) /* Port A, bit 1 */


/* LCD Panel bit-mapping.  */
#define EBCS_LCD_BIT_4    (BIT_4)
#define EBCS_LCD_BIT_5    (BIT_1)
#define EBCS_LCD_BIT_6    (BIT_6)
#define EBCS_LCD_BIT_7    (BIT_0)

#define EBCS_LCD_E        (BIT_2)
#define EBCS_LCD_RS       (BIT_3)
#define EBCS_BUTTON_ENABLE   (BIT_5)

#define EBCS_BUTTON_EN_1     (EBCS_LCD_BIT_5)
#define EBCS_BUTTON_EN_2     (EBCS_LCD_BIT_6)
#define EBCS_BUTTON_EN_3     (EBCS_LCD_BIT_4)
#define EBCS_BUTTON_EN_4     (EBCS_LCD_BIT_7)

#define EBCS_LCD_BRESET   (BIT_7)

#ifndef EBCS_KEY_PREV
# define EBCS_KEY_PREV BUTTON_1
#endif

#ifndef EBCS_KEY_NEXT
# define EBCS_KEY_NEXT  BUTTON_2
#endif

#ifndef EBCS_KEY_MINUS
# define EBCS_KEY_MINUS BUTTON_3
#endif

#ifndef EBCS_KEY_PLUS
# define EBCS_KEY_PLUS BUTTON_4
#endif

extern const char *const ebcs_version;
extern const char *const ebcs_date;
extern const char *const ebcs_author;

#endif
