/* humidity.h -- Humidity Monitor Interface
   Copyright 2001 Free Software Foundation, Inc.
   Written by Stephane Carrez (stcarrez@worldnet.fr)

This file is part of EBCS.

EBCS is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

EBCS is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with EBCS; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#ifndef _EBCS_HUMIDITY_H
#define _EBCS_HUMIDITY_H

#include <sys/param.h>
#include <gel/event.h>
#include <gel/timer.h>

#ifdef __cplusplus
extern "C" {
#endif

/*! @defgroup temperature Temperature Monitor Interface

 */
/*@{*/

typedef unsigned short humidity_t;

#define NR_TEMP_SAMPLES 32

/*! Statistics about the triac (ie, device ON/OFF stats).  */
struct humidity_monitor
{
  unsigned short factor;
  unsigned char  port;
  humidity_t     samples[NR_TEMP_SAMPLES];
  struct timer   timer_meas;
  struct timer   timer_samples;
  humidity_t     *sample_last;
  humidity_t  temp_current;
  unsigned short meas_period;
  unsigned short sample_period;
  humidity_t     cur_humidity;
};
typedef struct humidity_monitor humidity_monitor_t;


/*! Turn on or off the given triac.

  The triac identified by \i id is turned ON or OFF according to
  \i state.  If the triac state changes, an event is posted on
  the corresponding triac event object.

  @param id the triac identification
  @param state the new state of the triac (ON or OFF)

  @see triac_get, triac_events  */
extern unsigned get_humidity (humidity_monitor_t *mon);
  
extern void humidity_monitor_create (humidity_monitor_t *mon);
 
/*! Initialize humidity module.

    Setup the humidity module to measure the frequency on IC1 and IC2
    and report the humidity.  */
extern void humidity_initialize (humidity_monitor_t *mon);
 
/*@}*/

#ifdef __cplusplus
};
#endif
#endif
