/* debug-entry.s -- Debug Entry points
   Copyright 2001 Free Software Foundation, Inc.
   Written by Stephane Carrez (stcarrez@worldnet.fr)

This file is part of EBCS.

EBCS is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

EBCS is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with EBCS; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

top_nvram = 0x100

	;;
	;; Debug agent stack is in page0 NVRAM.
	;; It is defined so that we do not corrupt the bootstrap
	;; interrupt vectors.
	;; 
	.globl _debug_stack_top
_debug_stack_top = top_nvram - 32 * 2

	.sect .text

.macro vector label id
	.globl \label
\label:
	ldab	#2*\id
	bra	vec_common
.endm

vector vec_0 0
vector vec_1 1
vector vec_2 2
vector vec_3 3
vector vec_4 4
vector vec_5 5
vector vec_6 6
vector vec_7 7
vector vec_8 8
vector vec_9 9
vector vec_10 10
vector vec_11 11
vector vec_12 12
vector vec_13 13
vector vec_14 14
vector vec_15 15
vector vec_16 16
vector vec_17 17
vector vec_18 18
vector vec_19 19
vector vec_20 20
vector vec_21 21
vector vec_22 22
vector vec_23 23
vector vec_24 24
vector vec_25 25
vector vec_26 26
vector vec_27 27
vector vec_28 28
vector vec_29 29

	.globl vec_30
vec_30:
	ldab	#2*30
vec_common:
	;;
	;; Get the user vector and jump to it if it is not null.
	;;
	ldx	#_debug_user_vectors
	abx
	ldx	0,x
	beq	__enter_debug
	;;
	;; Call debugger if someting comes from serial line.
	;; 
	ldy	#_io_ports+0x2E
	brset	0,y #0x20 __enter_debug 
	jmp	0,x

;; 
;; Enter in the debug agent.
;; 
	.globl __enter_debug
__enter_debug:
	;;
	;; Save stack register and setup to debug agent stack.
	;; We must use our own stack to avoid problems if user's stack
	;; is wrong.
	;; 
	tsx
	lds	#_debug_stack_top
	ldy	*_.tmp
	pshy
	;;
	;; dbg_loop (char vector_id, void* user_stack)
	;;
	pshx
	jsr	dbg_loop
	;;
	;; Get new user stack (may have been changed by debugger).
	;; If the stack is changed, the debugger has also copied
	;; the registers to the new stack location, so that we
	;; have the good stack frame to return.
	;; 
	pulx
	puly
	sty	*_.tmp
	txs
	rti

#ifdef STACK_INFO
	.globl	mcount
mcount:
	psha
	pshb
	tsy
	xgdy
	cpd	stack_low
	bhi	mcount_done
	std	stack_low
mcount_done:
	pulb
	pula
	rts
#endif

;; 
;; Interrupt vectors are in a specific section that is
;; mapped at 0xffc0. For the example program, the reset handler
;; points to the generic crt0 entry point.
;;
	.sect .vectors
	.globl vectors
vectors:
	.word vec_0		; ffc0
	.word vec_1		; ffc2
	.word vec_2		; ffc4
	.word vec_3		; ffc6
	.word vec_4		; ffc8
	.word vec_5		; ffca
	.word vec_6		; ffcc
	.word vec_7		; ffce
	.word vec_8		; ffd0
	.word vec_9		; ffd2
	.word vec_10		; ffd4

	;; SCI
	.word vec_11		; ffd6

	;; SPI
	.word vec_12		; ffd8
	.word vec_13		; ffda (PAII)
	.word vec_14		; ffdc (PAOVI)
	.word vec_15		; ffde (TOI)

	;; Timer Output Compare
	.word vec_16		; ffe0
	.word vec_17		; ffe2
	.word vec_18		; ffe4
	.word vec_19		; ffe6
	.word vec_20		; ffe8

	;; Timer Input compare
	.word vec_21		; ffea
	.word vec_22		; ffec
	.word vec_23		; ffee

	;;  Misc
	.word vec_24		; fff0 (RTII)
	.word vec_25		; fff2 (IRQ)
	.word vec_26		; fff4 (XIRQ)
	.word vec_27		; fff6 (SWI)
	.word vec_28		; fff8 (ILL)
	.word vec_29		; fffa (COP Failure)
	.word vec_30		; fffc (COP Clock monitor)
	.word _start		; fffe (reset)

