/* ebcs.c -- Main entry point
   Copyright 2001 Free Software Foundation, Inc.
   Written by Stephane Carrez (stcarrez@worldnet.fr)

This file is part of GEL.

GEL is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GEL is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GEL; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include <sys/locks.h>
#include <sys/ports.h>
#include <sys/sio.h>
#include <sys/interrupts.h>
#include <lcd.h>
#include <gel/event.h>
#include <gel/panel.h>

#include <ebcs/ebcs.h>
#include <ebcs/board.h>
#include <ebcs/main-panel.h>
#include <ebcs/date-panel.h>
#include <ebcs/var-panel.h>
#include <ebcs/info-panel.h>
#include <ebcs/watchdog.h>

#define EVENT_QUEUE_SIZE 16

static event event_queue[EVENT_QUEUE_SIZE];

void input_capture_1_interrupt (void);
void input_capture_2_interrupt (void);

/* Forward declarations.  */
void ebcs_initialize_phase_1 (void);
void ebcs_initialize_phase_2 (void);

extern void _start ();
#if 0
struct interrupt_vectors __attribute__((section(".vectors"))) vectors = 
{
  vec_0, /* res0 */
  vec_1,
  vec_2,
  vec_3,
  vec_4,
  vec_5,
  vec_6,
  vec_7,
  vec_8,
  vec_9,
  vec_10, /* res 10 */
  vec_11, /* sci */
  vec_12, /* spi */
  vec_13, /* acc overflow */
  vec_14,
  timer_overflow_interrupt,
  vec_16, /* out compare 5 */
  vec_17, /* out compare 4 */
  vec_18, /* out compare 3 */
  vec_19, /* out compare 2 */
  vec_20, /* out compare 1 */
  vec_21, /* in capt 3 */
  input_capture_2_interrupt, /* in capt 2 */
  input_capture_1_interrupt, /* in capt 1 */
  timer_interrupt,
  vec_25, /* IRQ */
  vec_26, /* XIRQ */
  vec_27, /* swi */
  vec_28, /* illegal */
  vec_29,
  vec_30,
  _start
};
#endif

void
ebcs_initialize_phase_1 ()
{
  serial_init ();

  timer_initialize ();
  event_initialize (event_queue, EVENT_QUEUE_SIZE);
  lcd_reset ();
  button_initialize ();
  panel_initialize ();
  watchdog_initialize ();
}

void
ebcs_initialize_phase_2 ()
{
  main_panel_initialize ();
  date_panel_initialize ();
  var_panel_initialize ();
  button_enable ();
}

int
main ()
{
  ebcs_initialize_phase_1 ();
  ebcs_initialize_phase_2 ();
  panel_loop ();
}
