/* watchdog.c -- Watchdog Management
   Copyright 2001 Free Software Foundation, Inc.
   Written by Stephane Carrez (stcarrez@worldnet.fr)

This file is part of GEL.

GEL is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GEL is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GEL; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include <sys/locks.h>
#include <sys/ports.h>
#include <sys/sio.h>
#include <sys/interrupts.h>
#include <gel/timer.h>
#include <gel/event.h>

#include <ebcs/ebcs.h>
#include <ebcs/watchdog.h>

static event_callout watchdog_callout;
static struct event_def watchdog_event;

static struct timer watchdog_timer;
static unsigned char watchdog_pos = 0;

/* Watchdog timer.

   This is called each 500ms to post the watchdog_event event.
*/
static void
watchdog_timer_handler (struct timer *t)
{
  unsigned char c;
  unsigned long timeout;

  /* Post the watchdog event so that resetting the watchdog can
     be triggerred.  */
  event_post (&watchdog_event, 0);

  timeout = WATCHDOG_TIMEOUT;
  watchdog_pos++;
  c = watchdog_pos;

  /* Send something on serial line so that it produces some regular
     activity over there and it is observable remotely.  */
  if (c & 1)
    {
      if (c & 2)
	{
	  serial_send ('\b');
	  timeout = 50;
	}
      else
	{
	  serial_send ("-\\|/"[(c >> 2) & 3]);
	}
    }
  timer_create (t, timeout, watchdog_timer_handler, TIMER_UNMASK);
}

static void
watchdog_event_handler (event_callout *callout, event *ev)
{
  cop_reset ();
}

void
watchdog_initialize (void)
{
  event_register (&watchdog_event, &watchdog_callout,
		  watchdog_event_handler, 0);
  timer_create (&watchdog_timer, WATCHDOG_TIMEOUT,
		watchdog_timer_handler, TIMER_UNMASK);
}
