/* temperature.c -- Temperature Monitor Interface
   Copyright 2001 Free Software Foundation, Inc.
   Written by Stephane Carrez (stcarrez@worldnet.fr)

This file is part of GEL.

GEL is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GEL is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GEL; see the file COPYING.  If not, write to
the Free Software Foundation, 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.  */

#include <sys/locks.h>
#include <sys/ports.h>
#include <string.h>
#include <ebcs/ebcs.h>
#include <ebcs/temperature.h>

static temperature_t
collect_temperature (temperature_monitor_t *tmon)
{
  unsigned long v;
  temperature_t temp;
  unsigned char avalue;

  avalue = _io_ports[tmon->port];
  v = (unsigned long) (avalue) * 5L * 1000L * 1000L;
  v = v / (*tmon->factor * 256L);

  /* Round up the value and drop the digit.  */
  v += 4;
  v /= 10L;
  temp = (temperature_t) v;
  temp = (temp + tmon->temp_current) / 2;
  tmon->temp_current = temp;
  return temp;
}

/*! Collect the temperature samples.

    Read the analog input to collect the temperature sample.

*/
static void
temperature_sample_timer (struct timer *t)
{
  struct temperature_monitor *tmon = (struct temperature_monitor *) t->data;
  temperature_t temp;

  temp = collect_temperature (tmon);
  if (tmon->sample_last > &tmon->samples[NR_TEMP_SAMPLES])
    tmon->sample_last = tmon->samples;
  *tmon->sample_last = temp;

  timer_create (t, tmon->sample_period, temperature_sample_timer,
                TIMER_UNMASK);
}

void
create_temperature_monitor (temperature_monitor_t *tmon,
                            unsigned char port,
                            unsigned short *factor)
{
  tmon->factor = factor;
  tmon->port = port;
  memset (tmon->samples, 0, sizeof (tmon->samples));
  tmon->sample_last = tmon->samples;
  tmon->temp_current = 0;
  tmon->sample_period = 1000;
  tmon->timer_samples.data = tmon;
  timer_create (&tmon->timer_samples, tmon->sample_period,
                temperature_sample_timer, TIMER_UNMASK);
}

void
temperature_initialize ()
{
  _io_ports[M6811_OPTION] |= M6811_ADPU;
  _io_ports[M6811_ADCTL] = M6811_MULT | M6811_SCAN;
}
